summaryrefslogtreecommitdiff
path: root/src/cp.c
diff options
context:
space:
mode:
authorPaul Eggert <eggert@cs.ucla.edu>2004-09-13 12:12:26 +0000
committerPaul Eggert <eggert@cs.ucla.edu>2004-09-13 12:12:26 +0000
commit615d4b2cc83fb7d976d3a88ffbae2a10ba201541 (patch)
treedfae68600ec57c928c4882a58ed5991e25e898d8 /src/cp.c
parente6bcd96876db4fe6670a2b82e8d28af92f8e3acb (diff)
downloadcoreutils-615d4b2cc83fb7d976d3a88ffbae2a10ba201541.tar.xz
Adjust to backup enum rename.
Diffstat (limited to 'src/cp.c')
-rw-r--r--src/cp.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/cp.c b/src/cp.c
index 8b4e39ffb..46a0b0c40 100644
--- a/src/cp.c
+++ b/src/cp.c
@@ -648,20 +648,20 @@ do_copy (int n_files, char **file, const char *target_directory,
where SUFFIX is determined by any version control options used. */
if (x->unlink_dest_after_failed_open
- && x->backup_type != none
+ && x->backup_type != no_backups
&& STREQ (source, dest)
&& !new_dst && S_ISREG (sb.st_mode))
{
static struct cp_options x_tmp;
new_dest = find_backup_file_name (dest, x->backup_type);
/* Set x->backup_type to `none' so that the normal backup
mechanism is not used when performing the actual copy.
- backup_type must be set to `none' only *after* the above
+ backup_type must be set to `no_backups' only *after* the above
call to find_backup_file_name -- that function uses
backup_type to determine the suffix it applies. */
x_tmp = *x;
- x_tmp.backup_type = none;
+ x_tmp.backup_type = no_backups;
x = &x_tmp;
}
else
@@ -999,7 +999,7 @@ main (int argc, char **argv)
x.backup_type = (make_backups
? xget_version (_("backup type"),
version_control_string)
- : none);
+ : no_backups);
if (x.preserve_mode)
x.umask_kill = ~ (mode_t) 0;
@@ -648,20 +648,20 @@ do_copy (int n_files, char **file, const char *target_directory,
static struct cp_options x_tmp;
new_dest = find_backup_file_name (dest, x->backup_type);
- /* Set x->backup_type to `none' so that the normal backup
+ /* Set x->backup_type to `no_backups' so that the normal backup
mechanism is not used when performing the actual copy.